bpynodearrange
=======

A reimplementation of the [Node Arrange](https://github.com/Leonardo-Pike-Excell/node-arrange) addon for Blender. This repackages it as a python module for easier use by other addons.